@@ -1290,11 +1290,11 @@ draw_ant(ModeInfo * mi)
 
 		/* Allow step first and turn */
 		old_dir = ((status->direction < ANGLES) ? anant->direction : old_dir);
-#if DEBUG
+#ifdef DEBUG
 		(void) printf("old_dir %d, col %d, row %d", old_dir, anant->col, anant->row);
 #endif
 		position_of_neighbor(ap, old_dir, &(anant->col), &(anant->row));
-#if DEBUG
+#ifdef DEBUG
 		(void) printf(", ncol %d, nrow %d\n", anant->col, anant->row);
 #endif
 		draw_anant(mi, anant->direction, anant->col, anant->row);
