@@ -91,7 +91,7 @@ ModStruct   bug_description =
 
 #endif
 
-#if DEBUG
+#ifdef DEBUG
 #include <assert.h>
 #endif
 
@@ -1302,13 +1302,13 @@ draw_bug(ModeInfo * mi)
 		row = bp->currbug->info.row;
 		colrow = col + row * bp->ncols;
 		if (bp->currbug->info.energy-- < 0) {	/* Time to die, Bug */
-#if DEBUG
+#ifdef DEBUG
 			assert(bp->currbug == bp->arr[colrow]);
 #endif
 			/* back up one or else in void */
 			bp->currbug = bp->currbug->previous;
 			removefrom_buglist(bp, bp->arr[colrow]);
-#if DEBUG
+#ifdef DEBUG
 			assert(bp->arr[colrow] == 0);
 #endif
 			bp->arr[colrow] = 0;
@@ -1346,7 +1346,7 @@ draw_bug(ModeInfo * mi)
 				bp->currbug->info.col = ncol;
 				bp->currbug->info.row = nrow;
 				bp->currbug->info.direction = absdir;
-#if DEBUG
+#ifdef DEBUG
 				assert(bp->arr[ncolrow] == 0);
 #endif
 				bp->arr[ncolrow] = bp->currbug;
