@@ -2476,7 +2476,7 @@ release_lament(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_lament(MI_DISPLAY(mi), &lcs[screen]);
-		(void) free((void *) lcs);
+		free(lcs);
 		lcs = (lament_configuration *) NULL;
 	}
 	FreeAllGL(mi);
