@@ -779,7 +779,7 @@ void
 release_superquadrics(ModeInfo * mi)
 {
 	if (superquadrics != NULL) {
-		(void) free((void *) superquadrics);
+		free(superquadrics);
 		superquadrics = (superquadricsstruct *) NULL;
 	}
 	FreeAllGL(mi);
