@@ -2,7 +2,7 @@
 /* juggle */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)juggle.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)juggle.c	5.10 2003/09/02 xlockmore";
 
 #endif
 
@@ -22,6 +22,8 @@ static const char sccsid[] = "@(#)juggle.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History
+ * 02-Sep-2003: Non-real time to see what is happening without a strobe effect
+ *              for slow machines.
  * 01-Nov-2000: Allocation checks
  * 1996: Written
  */
@@ -119,29 +121,34 @@ so the answer is to do a single 661 and then drop straight down to (5).
 #ifdef MODE_juggle
 
 #define DEF_PATTERN "." /* All patterns */
-#define DEF_TRAIL "0" /* No trace */
+#define DEF_TAIL "0" /* No trace */
 #ifdef UNI
+/* Maybe a ROLA BOLA would be at a better angle for viewing */
 #define DEF_UNI "FALSE" /* No unicycle */ /* Not implemented yet */
 #endif
+#define DEF_REAL "TRUE"
 #define DEF_SOLID "FALSE" /* Not solid */
 
 static char *pattern;
-static int trail;
+static int tail;
 #ifdef UNI
 static Bool uni;
 #endif
+static Bool real;
 static Bool solid;
 
 static XrmOptionDescRec opts[] =
 {
   {(char* ) "-pattern", (char *) ".juggle.pattern",
    XrmoptionSepArg, (caddr_t) NULL},
-  {(char* ) "-trail", (char *) ".juggle.trail",
+  {(char* ) "-tail", (char *) ".juggle.tail",
    XrmoptionSepArg, (caddr_t) NULL},
 #ifdef UNI
   {(char *) "-uni", (char *) ".juggle.uni", XrmoptionNoArg, (caddr_t) "on"},
   {(char *) "+uni", (char *) ".juggle.uni", XrmoptionNoArg, (caddr_t) "off"},
 #endif
+  {(char *) "-real", (char *) ".juggle.real", XrmoptionNoArg, (caddr_t) "on"},
+  {(char *) "+real", (char *) ".juggle.real", XrmoptionNoArg, (caddr_t) "off"},
   {(char *) "-solid", (char *) ".juggle.solid", XrmoptionNoArg, (caddr_t) "on"},
   {(char *) "+solid", (char *) ".juggle.solid", XrmoptionNoArg, (caddr_t) "off"}
 };
@@ -149,22 +156,25 @@ static argtype vars[] =
 {
   {(caddr_t *) &pattern, (char *) "pattern",
    (char *) "Pattern", (char *) DEF_PATTERN, t_String},
-  {(caddr_t *) &trail, (char *) "trail",
-   (char *) "Trail", (char *) DEF_TRAIL, t_Int},
+  {(caddr_t *) &tail, (char *) "tail",
+   (char *) "Tail", (char *) DEF_TAIL, t_Int},
 #ifdef UNI
   {(caddr_t *) &uni, (char *) "uni",
    (char *) "Uni", (char *) DEF_UNI, t_Bool},
 #endif
+  {(caddr_t *) &real, (char *) "real",
+   (char *) "Real", (char *) DEF_REAL, t_Bool},
   {(caddr_t *) &solid, (char *) "solid",
    (char *) "Solid", (char *) DEF_SOLID, t_Bool}
 };
 static OptionStruct desc[] =
 {
   {(char *) "-pattern string", (char *) "Cambridge Juggling Pattern"},
-  {(char *) "-trail num", (char *) "Trace Juggling Patterns"},
+  {(char *) "-tail num", (char *) "Trace Juggling Patterns"},
 #ifdef UNI
   {(char *) "-/+uni", (char *) "Unicycle"},
 #endif
+  {(char *) "-/+real", (char *) "Real-time"},
   {(char *) "-/+solid", (char *) "solid color (else its a 4 panel look (half white))"}
 };
 
@@ -348,6 +358,7 @@ static patternstruct portfolio[] = {
   {(char *) "[4 3 +4]", (char *) "5 3 +4"},
   {(char *) "[+4 1]", (char *) "+7 1, 4 shower"},
   {(char *) "[4 4 4 4 0]", (char *) "5 5 5 5 0, learning 5"},
+  {(char *) "[+4 x4 =4]", (char *) "+4 x4 =4, Mill's mess for 4"},
   {(char *) "[5]", (char *) "5, 5 cascade"},
   {(char *) "[_5 _5 _5 _5 _5 5 5 5 5 5]", (char *) "_5 _5 _5 _5 _5 5 5 5 5 5, jump rope"},
   {(char *) "[+5 x5 =5]", (char *) "+5 x5 =5, Mill's mess for 5"},
@@ -1240,7 +1251,7 @@ init_juggle(ModeInfo * mi)
 	sp->arm[RIGHT][2].y = sp->cy + SY;
 
 	if (sp->trace == NULL) {
-	  if ((sp->trace = (XPoint *)calloc(trail, sizeof(XPoint))) == NULL) {
+	  if ((sp->trace = (XPoint *)calloc(tail, sizeof(XPoint))) == NULL) {
 		free_juggle(sp);
  		return;
 	  }
@@ -1372,6 +1383,11 @@ init_juggle(ModeInfo * mi)
 		return;
 
 	hands(sp);
+	if (!real) {
+	  struct timeval tv;
+	  (void)gettimeofday(&tv, NULL);
+	  sp->time = (int) ((tv.tv_sec - sp->begintime)*1000 + tv.tv_usec/1000);
+	}
 
 #ifdef OLDDEBUG
 	dump(sp);
@@ -1471,10 +1487,12 @@ draw_juggle(ModeInfo * mi)
 
 	draw_figure(mi);
 
-	{
+	if (real) {
 	  struct timeval tv;
 	  (void)gettimeofday(&tv, NULL);
 	  sp->time = (int) ((tv.tv_sec - sp->begintime)*1000 + tv.tv_usec/1000);
+	} else {
+	  sp->time += MI_DELAY(mi) / 1000;
 	}
 	for (traj = sp->head->next; traj != sp->head; traj = traj->next) {
 	  length++;
@@ -1500,12 +1518,12 @@ draw_juggle(ModeInfo * mi)
 		  draw_arm(mi, traj->hand, &x, &y);
 		}
 		if (traj->type == Ball || traj->type == Full) {
-		  if(trail > 0) {
+		  if(tail > 0) {
 			ERASE_BALL(sp->trace[sp->traceindex].x,
 				sp->trace[sp->traceindex].y);
 			sp->trace[sp->traceindex].x = traj->x;
 			sp->trace[sp->traceindex].y = traj->y;
-			if (++sp->traceindex >= trail) {
+			if (++sp->traceindex >= tail) {
 			  sp->traceindex = 0;
 			}
 		  } else {
