@@ -1111,7 +1111,7 @@ init_kaleid(ModeInfo * mi)
 	if (kp->PenCount < -MINPENS) {
 		/* if kp->PenCount is random ... the size can change */
 		if (kp->pen != NULL) {
-			(void) free((void *) kp->pen);
+			free(kp->pen);
 			kp->pen = (penstruct *) NULL;
 		}
 		kp->PenCount = NRAND(-kp->PenCount - MINPENS + 1) + MINPENS;
@@ -1315,7 +1315,7 @@ draw_kaleid(ModeInfo * mi)
 	}
 	if ((segs = (XSegment *) malloc(NumberOfSegments *
 			sizeof (XSegment))) == NULL) {
-		(void) free((void *) kp->pen);
+		free(kp->pen);
 		kp->pen = (penstruct *) NULL;
 		return;
 	}
@@ -1375,7 +1375,7 @@ draw_kaleid(ModeInfo * mi)
 	  
 
 	XSetLineAttributes(display, gc, 1, LineSolid, CapRound, JoinRound);
-	(void) free((void *) segs);
+	free(segs);
 }
 
 /*-
@@ -1391,9 +1391,9 @@ release_kaleid(ModeInfo * mi)
 			kaleidstruct *kp = &kaleids[screen];
 
 			if (kp->pen != NULL)
-				(void) free((void *) kp->pen);
+				free(kp->pen);
 		}
-		(void) free((void *) kaleids);
+		free(kaleids);
 		kaleids = (kaleidstruct *) NULL;
 	}
 }
