@@ -612,19 +612,19 @@ free_life1d(Display * display, life1dstruct * lp)
 		lp->init_bits = 0;
 	}
 	if (lp->newcells != NULL) {
-		(void) free((void *) lp->newcells);
+		free(lp->newcells);
 		lp->newcells = (unsigned char *) NULL;
 	}
 	if (lp->oldcells != NULL) {
-		(void) free((void *) lp->oldcells);
+		free(lp->oldcells);
 		lp->oldcells = (unsigned char *) NULL;
 	}
 	if (lp->buffer != NULL) {
-		(void) free((void *) lp->buffer);
+		free(lp->buffer);
 		lp->buffer = (unsigned char *) NULL;
 	}
 	if (lp->nextstate != NULL) {
-		(void) free((void *) lp->nextstate);
+		free(lp->nextstate);
 		lp->nextstate = (char *) NULL;
 	}
 	free_stuff(display, lp);
@@ -692,11 +692,11 @@ init_life1d(ModeInfo * mi)
 			   STIPPLESIZE, STIPPLESIZE);	/* grey */
 	}
 	if (lp->newcells != NULL)
-		(void) free((void *) lp->newcells);
+		free(lp->newcells);
 	if (lp->oldcells != NULL)
-		(void) free((void *) lp->oldcells);
+		free(lp->oldcells);
 	if (lp->buffer != NULL)
-		(void) free((void *) lp->buffer);
+		free(lp->buffer);
 	lp->width = MI_WIDTH(mi);
 	lp->height = MI_HEIGHT(mi);
 	if (lp->width < 2)
@@ -884,7 +884,7 @@ release_life1d(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_life1d(MI_DISPLAY(mi), &life1ds[screen]);
-		(void) free((void *) life1ds);
+		free(life1ds);
 		life1ds = (life1dstruct *) NULL;
 	}
 }
