@@ -1287,7 +1287,7 @@ init_adam(ModeInfo * mi)
 				}
 				break;
 		}
-#if DEBUGTEST
+#ifdef DEBUGTEST
 				/* (void) printf ("s %d  s %d \n", start.x, start.y); */
 		(void) printf ("%d %d %d %d %d\n",
      start.x + i + ((lp->bnrows / 2 % 2) ? -j / 2 : -(j + 1) / 2) - lp->bx,
@@ -1363,7 +1363,7 @@ init_adam(ModeInfo * mi)
 			    (lp->clockwise) ?
 			      self_reproducing_loop[j][ADAM_LOOPX - i - 1] :
 			      self_reproducing_loop[j][i];
-#if DEBUG
+#ifdef DEBUG
 		/* Draw right away */
 		drawcell(mi, start.x + dirx.x * i + diry.x * j - lp->bx,
 		 start.y + dirx.y * i + diry.y * j - lp->by,
