@@ -2,7 +2,7 @@
 /* penrose --- quasiperiodic tilings */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)penrose.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)penrose.c	5.09 2003/07/08 xlockmore";
 
 #endif
 
@@ -22,6 +22,7 @@ static const char sccsid[] = "@(#)penrose.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 08-Jul-2003: Mono made a little more interesting.
  * 01-Nov-2000: Allocation checks
  * 10-May-1997: Jamie Zawinski <jwz@jwz.org> compatible with xscreensaver
  * 09-Sep-1996: Written.
@@ -440,6 +441,14 @@ init_penrose(ModeInfo * mi)
 		/* Insure good contrast */
 		tp->thin_color = (NRAND(2 * MI_NPIXELS(mi) / 3) + tp->thick_color +
 				  MI_NPIXELS(mi) / 6) % MI_NPIXELS(mi);
+	} else {
+		if (LRAND() & 1) {
+			tp->thick_color = MI_WHITE_PIXEL(mi);
+			tp->thin_color = MI_BLACK_PIXEL(mi);
+		} else {
+			tp->thick_color = MI_BLACK_PIXEL(mi);
+			tp->thin_color = MI_WHITE_PIXEL(mi);
+		}
 	}
 	size = MI_SIZE(mi);
 	if (size < -MINSIZE)
@@ -662,10 +671,20 @@ draw_tile(fringe_node_c * v1, fringe_node_c * v2,
 			XSetForeground(display, gc, MI_PIXEL(mi, tp->thick_color));
 		else
 			XSetForeground(display, gc, MI_PIXEL(mi, tp->thin_color));
-	} else
-		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+	} else {
+		if ((vtype & VT_TYPE_MASK) == VT_THICK)
+			XSetForeground(display, gc, tp->thick_color);
+		else
+			XSetForeground(display, gc, tp->thin_color);
+	}
 	XFillPolygon(display, window, gc, pts, 4, Convex, CoordModeOrigin);
-	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+	if (MI_NPIXELS(mi) <= 2) {
+		if ((vtype & VT_TYPE_MASK) == VT_THICK)
+			XSetForeground(display, gc, tp->thin_color);
+		else
+			XSetForeground(display, gc, tp->thick_color);
+	} else
+		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 	XDrawLines(display, window, gc, pts, 5, CoordModeOrigin);
 
 	if (tp->ammann) {
@@ -683,7 +702,7 @@ draw_tile(fringe_node_c * v1, fringe_node_c * v2,
 			if (MI_NPIXELS(mi) > 2)
 				XSetForeground(display, gc, MI_PIXEL(mi, tp->thin_color));
 			else {
-				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+				XSetForeground(display, gc, tp->thin_color);
 				XSetLineAttributes(display, gc, 1, LineOnOffDash, CapNotLast, JoinMiter);
 			}
 			XDrawLine(display, window, gc,
@@ -697,7 +716,7 @@ draw_tile(fringe_node_c * v1, fringe_node_c * v2,
 			if (MI_NPIXELS(mi) > 2)
 				XSetForeground(display, gc, MI_PIXEL(mi, tp->thick_color));
 			else {
-				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+				XSetForeground(display, gc, tp->thick_color);
 				XSetLineAttributes(display, gc, 1, LineOnOffDash, CapNotLast, JoinMiter);
 			}
 			XDrawLine(display, window, gc,
@@ -1168,8 +1187,12 @@ add_random_tile(fringe_node_c * vertex, ModeInfo * mi)
 		/* Insure good contrast */
 		tp->thin_color = (NRAND(2 * MI_NPIXELS(mi) / 3) + tp->thick_color +
 				  MI_NPIXELS(mi) / 6) % MI_NPIXELS(mi);
-	} else
-		tp->thick_color = tp->thin_color = MI_WHITE_PIXEL(mi);
+	} else {
+		unsigned long temp = tp->thick_color;
+
+		tp->thick_color = tp->thin_color;
+		tp->thin_color = temp;
+	}
 	n_hits = match_rules(vertex, hits, False);
 	side = NRAND(2) ? S_LEFT : S_RIGHT;
 	n = find_completions(vertex, hits, n_hits, side, vtypes /*, False */ );
