@@ -294,29 +294,29 @@ static void print_board(polyominoesstruct *sp) {
   for (y=0;y<sp->height;y++) {
     for (x=0;x<sp->width;x++)
       if (ARRAY(x,y) == -1)
-        fprintf(stderr," ");
+        (void) fprintf(stderr," ");
       else
-        fprintf(stderr,"%c",'a'+ARRAY(x,y));
-    fprintf(stderr,"\n");
+        (void) fprintf(stderr,"%c",'a'+ARRAY(x,y));
+    (void) fprintf(stderr,"\n");
   }
-  fprintf(stderr,"\n");
+  (void) fprintf(stderr,"\n");
 }
 
 static void print_points(point_type *point, int len) {
   int i;
 
   for (i=0;i<len;i++)
-    fprintf(stderr,"(%d %d) ",point[i].x,point[i].y);
+    (void) fprintf(stderr,"(%d %d) ",point[i].x,point[i].y);
 }
 
 static void print_polyomino(polyomino_type poly) {
   int i;
 
   print_points(poly.point,poly.len);
-  fprintf(stderr,"\n");
+  (void) fprintf(stderr,"\n");
   for (i=0;i<poly.transform_len;i++)
-    fprintf(stderr,"%d ",poly.transform_list[i]);
-  fprintf(stderr,"\n");
+    (void) fprintf(stderr,"%d ",poly.transform_list[i]);
+  (void) fprintf(stderr,"\n");
 }
 */
 
@@ -1048,12 +1048,12 @@ static void free_polyominoes(polyominoesstruct *sp) {
 }
 
 #define set_allocate(p,type,size) p = (type *) malloc(size);		\
-                             if ((p)==NULL) {free_polyominoes(sp);return 0;}
+  if ((p)==NULL) {free_polyominoes(sp);return 0;}
 
 #define copy_polyomino(dst,src,new_rand)				\
   (dst).len=(src).len;							\
   (dst).max_white = (src).max_white;					\
-  set_allocate((dst).point,point_type,sizeof(point_type)*(src).len);		\
+  set_allocate((dst).point,point_type,sizeof(point_type)*(src).len);	\
   (dst).len = (src).len;						\
   if (new_rand)								\
     random_permutation((src).len,perm_point);				\
@@ -1466,7 +1466,8 @@ xx
 
 static struct pentomino_struct one_sided_pentomino[60];
 
-void make_one_sided_pentomino(void) {
+static void
+make_one_sided_pentomino(void) {
   int i,j,t,u;
 
   j=0;
@@ -1487,7 +1488,8 @@ void make_one_sided_pentomino(void) {
 
 static struct hexomino_struct one_sided_hexomino[60];
 
-void make_one_sided_hexomino(void) {
+static void
+make_one_sided_hexomino(void) {
   int i,j,t,u;
 
   j=0;
@@ -2283,7 +2285,7 @@ draw_polyominoes(ModeInfo * mi) {
     draw_without_bitmaps(mi,sp);
 
   if (sp->nr_attached == sp->nr_polyominoes)
-    sp->wait = 100;
+    sp->wait = 500;
   else
     sp->wait = 0;
 }
@@ -2295,7 +2297,7 @@ release_polyominoes(ModeInfo * mi) {
   if (polyominoeses != NULL) {
     for (screen=0;screen<MI_NUM_SCREENS(mi); screen++)
       free_polyominoes(&polyominoeses[screen]);
-    (void) free((void *) polyominoeses);
+    free(polyominoeses);
     polyominoeses = (polyominoesstruct *) NULL;
   }
 }
