@@ -286,7 +286,7 @@ removefrom_list(CellList * ptr)
 {
 	ptr->previous->next = ptr->next;
 	ptr->next->previous = ptr->previous;
-	(void) free((void *) ptr);
+	free(ptr);
 }
 
 static void
@@ -298,7 +298,7 @@ flush_list(voterstruct * vp)
 		curr = vp->last->previous;
 		curr->previous->next = vp->last;
 		vp->last->previous = curr->previous;
-		(void) free((void *) curr);
+		free(curr);
 	}
 }
 
@@ -583,15 +583,15 @@ free_voters(voterstruct *vp)
 {
 	if (vp->first != NULL) {
 		flush_list(vp);
-		(void) free((void *) vp->first);
+		free(vp->first);
 		vp->first = (CellList *) NULL;
 	}
 	if (vp->last != NULL) {
-		(void) free((void *) vp->last);
+		free(vp->last);
 		vp->last = (CellList *) NULL;
 	}
 	if (vp->arr != NULL) {
-		(void) free((void *) vp->arr);
+		free(vp->arr);
 		vp->arr = (char *) NULL;
 	}
 }
@@ -745,7 +745,7 @@ init_voters(ModeInfo * mi)
 
 	vp->npositions = vp->ncols * vp->nrows;
 	if (vp->arr != NULL)
-		(void) free((void *) vp->arr);
+		free(vp->arr);
 	if ((vp->arr = (char *) calloc(vp->npositions, sizeof (char))) == NULL) {
 		free_voters(vp);
 		return;
@@ -853,7 +853,7 @@ release_voters(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_voters(&voters[screen]);
-		(void) free((void *) voters);
+		free(voters);
 		voters = (voterstruct *) NULL;
 	}
 }
