@@ -73,6 +73,25 @@ my_fopen(char *filename, const char *type)
 	return fp;
 }
 
+FILE       *
+my_fopenSize(char *filename, const char *type, int *size)
+{
+	FILE       *fp = (FILE *) NULL;
+	int         s;
+	struct stat fileStat;
+
+	s = stat(filename, &fileStat);
+	*size = fileStat.st_size;
+	if ((s >= 0 && S_ISREG(fileStat.st_mode)) || (s < 0 && type[0] == 'w')) {
+		if ((fp = fopen(filename, type)) == NULL)
+			return (FILE *) NULL;
+	} else {
+		return (FILE *) NULL;
+	}
+
+	return fp;
+}
+
 #if HAVE_DIRENT_H
 static void
 randomFileFromList(char *directory,
