@@ -87,11 +87,12 @@ static login_cap_t *rlc = NULL;
 #include <syslog.h>
 #endif
 
-#if ( HAVE_FCNTL_H && (defined( USE_MULTIPLE_ROOT ) || defined( USE_MULTIPLE_USER )))
-#include <fcntl.h>
 #include <errno.h>
 extern int  errno;
 
+#if ( HAVE_FCNTL_H && (defined( USE_MULTIPLE_ROOT ) || defined( USE_MULTIPLE_USER )))
+#include <fcntl.h>
+
 void        get_multiple(struct passwd *);
 void        set_multiple(int uid);
 
@@ -434,6 +435,10 @@ extern char *crypt(const char *, const char *);
 #endif
 #endif
 
+#ifdef PASSWD_HELPER_PROGRAM
+static int	run_helper(const char *user, const char *pass);
+#endif
+
 #if (defined( USE_XLOCKRC ) || (!defined( OSF1_ENH_SEC ) && !defined( HP_PASSWDETC ) && !defined( VMS )))
 static struct passwd *
 my_passwd_entry(void)
@@ -1406,6 +1411,12 @@ checkPasswd(char *buffer)
 #endif /* !PAM */
 #endif /* !DCE_PASSWD */
 #endif /* !VMS */
+
+#ifdef PASSWD_HELPER_PROGRAM
+	if (!done && !(done = run_helper(user, buffer)) && allowroot)
+		done = run_helper(ROOT, buffer);
+#endif
+
 	return done;
 }
 
@@ -2250,3 +2261,60 @@ int checkGroupXlockPasswds(char *buffer)
 	return False;
 }
 #endif
+
+#ifdef PASSWD_HELPER_PROGRAM
+#include <signal.h>
+
+static int
+run_helper(const char *user, const char *pass)
+{
+  sigset_t sigset;
+  int pfd[2], status;
+  pid_t pid;
+
+  if (pipe(pfd) < 0)
+    return 0;
+
+  sigemptyset(&sigset);
+  sigaddset(&sigset, SIGCHLD);
+  sigprocmask(SIG_BLOCK, &sigset, &sigset);
+
+  if ((pid = fork()) < 0) {
+    close(pfd[0]);
+    close(pfd[1]);
+    return 0;
+  }
+
+  if (pid == 0) {
+    close(pfd[1]);
+    if (pfd[0] != 0)
+      dup2(pfd[0], 0);
+
+    /* Helper is invoked as helper service-name [user] */
+    execlp(PASSWD_HELPER_PROGRAM, PASSWD_HELPER_PROGRAM,"xlock", user, NULL);
+    error("Failed to execute " PASSWD_HELPER_PROGRAM);
+    exit(1);
+  }
+
+  close(pfd[0]);
+
+  /* Write out password to helper process */
+  if (!pass)
+    pass = "";
+  write(pfd[1], pass, strlen(pass));
+  close(pfd[1]);
+
+  while (waitpid(pid, &status, 0) < 0) {
+    if (errno == EINTR)
+      continue;
+    sigprocmask(SIG_SETMASK, &sigset, NULL);
+    return 0;
+  }
+
+  sigprocmask(SIG_SETMASK, &sigset, NULL);
+
+  if (!WIFEXITED(status) || WEXITSTATUS(status) != 0)
+    return 0;
+  return 1;
+}
+#endif
