@@ -13,6 +13,9 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
  * Revision History:
  *
  * Changes maintained by David Bagley <bagleyd@tux.org>
+ * 02-Dec-03: Jouk Jansen <joukj@hrem.stm.tudelft.nl>
+ *            On OpenVMS when TCPIP is switched off gethostname does not
+ *            work, in that case LIB$GETSYI to get the DECNET nodename.
  * 19-Jun-98: batchcount depreciated.  Use count instead.  batchcount still
  *            works for commandline.
  * 01-May-97: Matthew Rench <mdrench@mtu.edu>
@@ -78,6 +81,10 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
 # else
 #  include <socket.h>
 # endif
+# include <descrip>
+# include <ssdef>
+# include <syidef>
+# include <lib$routines>
 #endif
 
 #ifdef __sgi
@@ -100,9 +107,7 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
 
 #ifndef DEF_FILESEARCHPATH
 # ifdef VMS
-#  include <descrip>
 #  include <iodef>
-#  include <ssdef>
 #  include <stsdef>
 #  include <types.h>
 #  include <starlet.h>
@@ -162,49 +167,21 @@ static int  descr();
 #define DEF_PLANFONT     "-adobe-courier-medium-r-*-*-14-*-*-*-m-*-iso8859-1"
 #ifdef USE_MB
 # define DEF_FONTSET	DEF_FONT ## ",-*-*-medium-r-normal--24-*"
-#endif
+#endif /* USE MB */
 #define DEF_BG		"White"
 #define DEF_FG		"Black"
-#ifdef FR
-# define DEF_NAME	"Nom: "
-# define DEF_PASS	"Mot de passe: "
-# define DEF_VALID	"Validation ..."
-# define DEF_INVALID	"Mot de passe Invalide."
-# define DEF_INVALIDCAPSLOCK	"Mot de passe Invalide, Caps Lock on."
-# define DEF_INFO	"Entrez le mot de passe ou choisissez l'icone pour verrouiller."
-# define DEF_COUNT_FAILED	" essais chou."
-# define DEF_COUNTS_FAILED	" essais chous."
+
+/* language depended resources */
+#if defined FR
+#include "resource-msg-fr.h"
+#elif defined NL
+#include "resource-msg-nl.h"
+#elif defined JA
+#include "resource-msg-ja.h"
 #else
-#if defined NL
-# define DEF_NAME	"Naam: "
-# define DEF_PASS	"Wachtwoord: "
-# define DEF_VALID	"Aan het checken ..."
-# define DEF_INVALID	"Ongeldig wachtwoord."
-# define DEF_INVALIDCAPSLOCK    "Ongeldig wachtwoord, Hoofdlettertoets ingedrukt."
-# define DEF_INFO       "Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergrendelen."
-#ifdef HAVE_KRB5
-#define DEF_KRBINFO   "Geef Kerberos wachtwoord om te ontgrendelen ; selecteer het icoon om te vergrendelen."
-#endif /* HAVE_KRB5 */
-# define DEF_COUNT_FAILED	" mislukte poging."
-# define DEF_COUNTS_FAILED	" mislukte pogingen."
-#else
-#if defined JP
-# include "resource-msg-jp.h"
-#else
-# define DEF_NAME	"Name: "
-# define DEF_PASS	"Password: "
-# define DEF_VALID	"Validating login..."
-# define DEF_INVALID	"Invalid login."
-# define DEF_INVALIDCAPSLOCK	"Invalid login, Caps Lock on."
-# define DEF_INFO	"Enter password to unlock; select icon to lock."
-#ifdef HAVE_KRB5
-#define DEF_KRBINFO   "Enter Kerberos password to unlock; select icon to lock."
-#endif /* HAVE_KRB5 */
-# define DEF_COUNT_FAILED	" failed attempt."
-# define DEF_COUNTS_FAILED	" failed attempts."
-#endif
-#endif
+#include "resource-msg-en.h"
 #endif
+
 #ifdef GLOBAL_UNLOCK
 # define DEF_GUSER "Username: "
 #endif
@@ -304,32 +281,6 @@ static int  descr();
 #   define DEF_BUTTON_LOGOUT "0"	/* User Default, can be overridden */
 #  endif
 # endif
-
-# ifdef FR
-#  define DEF_BTN_LABEL	"Logout"
-#  define DEF_BTN_HELP	"Cliquer ici pour etre deloger"
-#  define DEF_FAIL	"Auto-logout a echoue"
-# else
-#ifdef NL
-#  define DEF_BTN_LABEL "Loguit"
-#  define DEF_BTN_HELP  "klik hier om uit te loggen"
-#  define DEF_FAIL  "Auto-loguit mislukt"
-# else
-#ifdef JP
-#  include "resource-msg-jp.h"
-# else
-#  define DEF_BTN_LABEL	"Logout"	/* string that appears in logout button */
-
-/* this string appears immediately below logout button */
-#  define DEF_BTN_HELP	"Click here to logout"
-
-/* this string appears in place of the logout button if user could not be
-   logged out */
-#  define DEF_FAIL	"Auto-logout failed"
-
-# endif
-#endif
-#endif
 #endif
 
 /* For modes with text, marquee & nose */
@@ -498,6 +449,9 @@ static XrmOptionDescRec genTable[] =
 #endif
 	{(char *) "-startCmd", (char *) ".startCmd", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-endCmd", (char *) ".endCmd", XrmoptionSepArg, (caddr_t) NULL},
+#ifndef VMS
+	{(char *) "-pipepassCmd", (char *) ".pipepassCmd", XrmoptionSepArg, (caddr_t) NULL},
+#endif
 	{(char *) "-logoutCmd", (char *) ".logoutCmd", XrmoptionSepArg, (caddr_t) NULL},
 
 	{(char *) "-mailCmd", (char *) ".mailCmd", XrmoptionSepArg, (caddr_t) ""},
@@ -707,6 +661,9 @@ static OptionStruct opDesc[] =
 #endif
 	{(char *) "-startCmd string", (char *) "command to run at locktime"},
 	{(char *) "-endCmd string", (char *) "command to run when unlocking"},
+#ifndef VMS
+	{(char *) "-pipepassCmd string", (char *) "command into which to pipe the password when unlocking"},
+#endif
       {(char *) "-logoutCmd string", (char *) "command to run when automatically logging out"},
 	{(char *) "-mailCmd string", (char *) "command to run to check for mail"},
 	{(char *) "-mailIcon string", (char *) "Icon to display when there is mail"},
@@ -865,6 +822,9 @@ char       *invalidsound;
 
 char       *startCmd;
 char       *endCmd;
+#ifndef VMS
+char       *pipepassCmd;
+#endif
 char       *logoutCmd;
 
 char       *mailCmd;
@@ -986,6 +946,9 @@ static argtype genvars[] =
 #endif
 	{(caddr_t *) & startCmd, (char *) "startCmd", (char *) "StartCmd", (char *) "", t_String},
 	{(caddr_t *) & endCmd, (char *) "endCmd", (char *) "EndCmd", (char *) "", t_String},
+#ifndef VMS
+	{(caddr_t *) & pipepassCmd, (char *) "pipepassCmd", (char *) "PipePassCmd", (char *) "", t_String},
+#endif
 	{(caddr_t *) & logoutCmd, (char *) "logoutCmd", (char *) "LogoutCmd", (char *) "", t_String},
 #ifdef USE_DPMS
 	{(caddr_t *) & dpmsstandby, (char *) "dpmsstandby", (char *) "DPMSStandby", (char *) DEF_DPMSSTANDBY, t_Int},
@@ -1534,6 +1497,21 @@ extern int  gethostname(char *, size_t);
 		remote = True;
 
 	if (gethostname(hostname, MAXHOSTNAMELEN)) {
+#ifdef VMS
+	    int val;
+	    struct dsc$descriptor itemval;
+
+	    itemval.dsc$w_length = MAXHOSTNAMELEN;
+	    itemval.dsc$b_dtype = 0;
+	    itemval.dsc$b_class = 0;
+	    itemval.dsc$a_pointer = hostname;
+
+	    val = SYI$_NODENAME;
+
+	    if ( LIB$GETSYI( &val , 0 , &itemval , 0 , 0 , 0 ) != SS$_NORMAL )
+	    {
+#endif
+
 		buf = (char *) malloc(strlen(ProgramName) + 80);
 		(void) sprintf(buf,
 			   "%s: Can not get local hostname.\n", ProgramName);
@@ -1541,6 +1519,7 @@ extern int  gethostname(char *, size_t);
 		free(buf);	/* Should never get here */
 	}
 #ifdef VMS
+	}
 	if (!remote && ((displayname[0] == '_') |
 			((displayname[0] == 'W') &
 			 (displayname[1] == 'S') &
